@@ -1,12 +1,12 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 1.48 2003/12/23 06:08:38 bkorb Exp $
+ *  $Id: autogen.h,v 1.53 2004/02/15 02:36:09 bkorb Exp $
  *  Global header file for AutoGen
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -27,12 +27,68 @@
 #ifndef AUTOGEN_HDR_H
 #define AUTOGEN_HDR_H
 
-#include "agUtils.h"
+#include "compat/compat.h"
+#include "config.h"
+
+#if defined(HAVE_FOPENCOOKIE) || defined(HAVE_FUNOPEN)
+#  define ENABLE_FMEMOPEN
+#endif
+
+#include REGEX_HEADER
+#include <guile/gh.h>
+
+#include "opts.h"
+#include "directive.h"
+#include "snprintfv/printf.h"
+
+#ifndef STR
+#  define _STR(s) #s
+#  define STR(s)  _STR(s)
+#endif
+
+#define ISNAMECHAR( c ) (isalnum(c) || ((c) == '_') || ((c) == '-'))
+
+#define STRSIZE( s )  (sizeof(s)-1)
+
+#ifdef DEFINING
+#  define VALUE( s )  = s
+#  define MODE
+#else
+#  define VALUE( s )
+#  define MODE extern
+#endif
+
+#define YYSTYPE t_word
+
+/*
+ *  Dual pipe opening of a child process
+ */
+typedef struct {
+    int     readFd;
+    int     writeFd;
+}  tFdPair;
+
+typedef struct {
+    FILE*   pfRead;  /* parent read fp  */
+    FILE*   pfWrite; /* parent write fp */
+}  tpfPair;
+
+#define NOPROCESS   ((pid_t)-1)
+#define NULLPROCESS ((pid_t)0)
+
+typedef unsigned char* tpChar;
+
 #include "expr.h"
 #include "autoopts/autoopts.h"
 #include "streqv.h"
 
 #include "cgi-fsm.h"
+#include "defParse-fsm.h"
+
+typedef union {
+    tpChar      pzStr;
+    char        ch;
+} def_token_u_t;
 
 #define STATE_TABLE           /* set up `atexit' and load Guile   */  \
     _State_( INIT )           /* processing command line options  */  \
@@ -162,12 +218,17 @@ typedef enum {
 
 #define NO_INDEX ((short)0x80DEAD)
 
-typedef struct def_stack tDefStack;
-struct def_stack {
+typedef struct sDefCtx tDefCtx;
+struct sDefCtx {
     tDefEntry* pDefs;        /* ptr to current def set     */
-    tDefStack* pPrev;        /* ptr to previous def set    */
+    tDefCtx*   pPrev;        /* ptr to previous def set    */
 };
 
+typedef union {
+    tDefEntry*  pDefEntry;
+    char*       pzText;
+} uDefValue;
+
 struct defEntry {
     tDefEntry* pNext;        /* next member of same level  */
     tDefEntry* pTwin;        /* next member with same name */
@@ -176,7 +237,7 @@ struct defEntry {
     char*      pzDefName;    /* name of this member        */
     teValType  valType;      /* text/block/not defined yet */
     long       index;        /* index among twins          */
-    char*      pzValue;      /* string or list of children */
+    uDefValue  val;          /* string or list of children */
 };
 
 struct scanContext {
@@ -235,6 +296,16 @@ struct for_state {
     ag_bool      for_firstFor;
 };
 
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ *
+ *  Parsing stuff
+ */
+typedef struct {
+    int     entryCt;
+    int     allocCt;
+    char*   entries[1];
+} tList;
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL VARIABLES
@@ -278,8 +349,8 @@ MODE tCC*        pzShellProgram   VALUE( NULL );
  *  and mFunc_For.  They are the only routines that dynamically
  *  push name/value pairs on the definition stack.
  */
-MODE tDefStack   currDefCtx       VALUE( { NULL } );
-MODE tDefStack   rootDefCtx       VALUE( { NULL } );
+MODE tDefCtx     currDefCtx       VALUE( { NULL } );
+MODE tDefCtx     rootDefCtx       VALUE( { NULL } );
 MODE tTemplate*  pCurTemplate     VALUE( NULL );
 MODE tCC*        pzLastScheme     VALUE( NULL );
 
@@ -312,6 +383,14 @@ MODE char        zStartMac[  8 ]  VALUE( "" );
  */
 MODE char*       pzDefineData     VALUE( NULL );
 MODE size_t      defineDataSize   VALUE( 0 );
+MODE char*       pz_token         VALUE( NULL );
+MODE te_dp_event lastToken        VALUE( DP_EV_INVALID );
+
+MODE int         stackDepth       VALUE( 0 );
+MODE int         stackSize        VALUE( 16 );
+MODE tDefEntry*  parseStack[16]   VALUE( { 0 } );
+MODE tDefEntry** ppParseStack     VALUE( parseStack );
+MODE tDefEntry*  pCurrentEntry    VALUE( NULL );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -339,9 +418,24 @@ extern void unloadDefs( void );
  *  GLOBAL PROCEDURES
  */
 #ifndef HAVE_STRLCPY
-size_t strlcpy( char* dest, const char* src, size_t n );
+extern size_t strlcpy( char* dest, const char* src, size_t n );
 #endif
+#ifdef ENABLE_FMEMOPEN
+/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ *
+ *  IF we have fopencookie or funopen, then we also have our own fmemopen...
+ *
+ *  Special ioctl/"seek" requests
+ */
+#define FMEM_IOCTL_BUF_ADDR  0x80000001
 
+/*
+ *  Save the buffer on close
+ */
+#define FMEM_IOCTL_SAVE_BUF  0x80000002
+
+extern FILE * fmemopen (void *buf, size_t len, const char *mode);
+#endif
 #include "proto.h"
 
 typedef union {
