@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Sunday January  4, 2004 at 03:13:35 PM PST
+ *  It has been AutoGen-ed  Monday February 23, 2004 at 06:59:16 PM PST
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  Copyright (c) 2001-2003  by  Bruce Korb
+ *  Copyright (c) 2001-2004  by  Bruce Korb
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -69,10 +69,9 @@ typedef enum {
     CGI_TR_NAME_EQUAL,
     CGI_TR_SEPARATE,
     CGI_TR_STASH,
-    CGI_TR_VALUE_ESCAPE,
-    CGI_TR_VALUE_SPACE
+    CGI_TR_VALUE_ESCAPE
 } te_cgi_trans;
-#define CGI_TRANSITION_CT  6
+#define CGI_TRANSITION_CT  5
 
 /*
  *  the state transition handling map
@@ -80,73 +79,85 @@ typedef enum {
  *  the new state and the transition enumeration code (in that order).
  *  It is indexed by first the current state and then the event code.
  */
-typedef struct transition t_transition;
-struct transition {
+typedef struct cgi_transition t_cgi_transition;
+struct cgi_transition {
     te_cgi_state  next_state;
     te_cgi_trans  transition;
 };
-static const t_transition
+static const t_cgi_transition
 cgi_trans_table[ CGI_STATE_CT ][ CGI_EVENT_CT ] = {
-  { { CGI_ST_NAME, CGI_TR_STASH },                  /* init state */
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID } },
 
-  { { CGI_ST_NAME, CGI_TR_STASH },                  /* name state */
-    { CGI_ST_NAME, CGI_TR_STASH },
-    { CGI_ST_VALUE, CGI_TR_NAME_EQUAL },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID },
-    { CGI_ST_INVALID, CGI_TR_INVALID } },
+  /* STATE 0:  CGI_ST_INIT */
+  { { CGI_ST_NAME, CGI_TR_STASH },                  /* EVT:  alpha */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  name_char */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  = */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  + */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  % */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  other */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  & */
+    { CGI_ST_INVALID, CGI_TR_INVALID }              /* EVT:  end */
+  },
 
-  { { CGI_ST_VALUE, CGI_TR_STASH },                 /* value state */
-    { CGI_ST_VALUE, CGI_TR_STASH },
-    { CGI_ST_VALUE, CGI_TR_STASH },
-    { CGI_ST_VALUE, CGI_TR_VALUE_SPACE },
-    { CGI_ST_VALUE, CGI_TR_VALUE_ESCAPE },
-    { CGI_ST_VALUE, CGI_TR_STASH },
-    { CGI_ST_INIT, CGI_TR_SEPARATE },
-    { CGI_ST_DONE, CGI_TR_SEPARATE } }
+
+  /* STATE 1:  CGI_ST_NAME */
+  { { CGI_ST_NAME, CGI_TR_STASH },                  /* EVT:  alpha */
+    { CGI_ST_NAME, CGI_TR_STASH },                  /* EVT:  name_char */
+    { CGI_ST_VALUE, CGI_TR_NAME_EQUAL },            /* EVT:  = */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  + */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  % */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  other */
+    { CGI_ST_INVALID, CGI_TR_INVALID },             /* EVT:  & */
+    { CGI_ST_INVALID, CGI_TR_INVALID }              /* EVT:  end */
+  },
+
+
+  /* STATE 2:  CGI_ST_VALUE */
+  { { CGI_ST_VALUE, CGI_TR_STASH },                 /* EVT:  alpha */
+    { CGI_ST_VALUE, CGI_TR_STASH },                 /* EVT:  name_char */
+    { CGI_ST_VALUE, CGI_TR_STASH },                 /* EVT:  = */
+    { CGI_ST_VALUE, CGI_TR_STASH },                 /* EVT:  + */
+    { CGI_ST_VALUE, CGI_TR_VALUE_ESCAPE },          /* EVT:  % */
+    { CGI_ST_VALUE, CGI_TR_STASH },                 /* EVT:  other */
+    { CGI_ST_INIT, CGI_TR_SEPARATE },               /* EVT:  & */
+    { CGI_ST_DONE, CGI_TR_SEPARATE }                /* EVT:  end */
+  }
 };
 
 
+#ifndef HAVE_ZBOGUS
+#define HAVE_ZBOGUS
 /*
- *  Define all the event and state names
+ *  Define all the event and state names, once per compile unit.
  */
 tSCC zBogus[]     = "** OUT-OF-RANGE **";
-tSCC zStInit[]    = "init";
-tSCC zEvInvalid[] = "* Invalid Event *";
 tSCC zFsmErr[]    =
     "FSM Error:  in state %d (%s), event %d (%s) is invalid\n";
+#endif /* HAVE_ZBOGUS */
+tSCC zCgiStInit[]    = "init";
+tSCC zCgiStName[] = "name";
+tSCC zCgiStValue[] = "value";
+tSCC* apzCgiStates[] = {
+    zCgiStInit,  zCgiStName,  zCgiStValue };
 
-tSCC zStName[] = "name";
-tSCC zStValue[] = "value";
-tSCC* apzStates[] = {
-    zStInit,  zStName,  zStValue };
-
-tSCC zEvAlpha[] = "alpha";
-tSCC zEvName_Char[] = "name_char";
-tSCC zEvEqual[] = "equal";
-tSCC zEvSpace[] = "space";
-tSCC zEvEscape[] = "escape";
-tSCC zEvOther[] = "other";
-tSCC zEvSeparator[] = "separator";
-tSCC zEvEnd[] = "end";
-tSCC* apzEvents[] = {
-    zEvAlpha,     zEvName_Char, zEvEqual,     zEvSpace,     zEvEscape,
-    zEvOther,     zEvSeparator, zEvEnd,       zEvInvalid };
+tSCC zCgiEvInvalid[] = "* Invalid Event *";
+tSCC zCgiEvAlpha[] = "alpha";
+tSCC zCgiEvName_Char[] = "name_char";
+tSCC zCgiEvEqual[] = "=";
+tSCC zCgiEvSpace[] = "+";
+tSCC zCgiEvEscape[] = "%";
+tSCC zCgiEvOther[] = "other";
+tSCC zCgiEvSeparator[] = "&";
+tSCC zCgiEvEnd[] = "end";
+tSCC* apzCgiEvents[] = {
+    zCgiEvAlpha,     zCgiEvName_Char, zCgiEvEqual,     zCgiEvSpace,
+    zCgiEvEscape,    zCgiEvOther,     zCgiEvSeparator, zCgiEvEnd,
+    zCgiEvInvalid };
 
 #define CGI_EVT_NAME(t) ( (((unsigned)(t)) >= CGI_EV_INVALID) \
-    ? zBogus : apzEvents[ t ])
+    ? zBogus : apzCgiEvents[ t ])
 
 #define CGI_STATE_NAME(s) ( (((unsigned)(s)) > CGI_ST_INVALID) \
-    ? zBogus : apzStates[ s ])
+    ? zBogus : apzCgiStates[ s ])
 
 #ifndef EXIT_FAILURE
 # define EXIT_FAILURE 1
@@ -206,7 +217,7 @@ cgi_run_fsm(
             else switch (curCh) {
             case '_': trans_evt = CGI_EV_NAME_CHAR; break;
             case '=': trans_evt = CGI_EV_EQUAL;     break;
-            case '+': trans_evt = CGI_EV_SPACE;     break;
+            case '+': trans_evt = CGI_EV_SPACE;     curCh = ' '; break;
             case '%': trans_evt = CGI_EV_ESCAPE;    break;
             case '&': trans_evt = CGI_EV_SEPARATOR; break;
             default:  trans_evt = CGI_EV_OTHER;     break;
@@ -219,7 +230,7 @@ cgi_run_fsm(
             nxtSt = CGI_ST_INVALID;
             trans = CGI_TR_INVALID;
         } else {
-            const t_transition* pTT = cgi_trans_table[ cgi_state ] + trans_evt;
+            const t_cgi_transition* pTT = cgi_trans_table[ cgi_state ] + trans_evt;
             nxtSt = firstNext = pTT->next_state;
             trans = pTT->transition;
         }
@@ -238,6 +249,7 @@ cgi_run_fsm(
             /* END   == INVALID == DO NOT CHANGE THIS COMMENT */
             break;
 
+
         case CGI_TR_NAME_EQUAL:
             /* START == NAME_EQUAL == DO NOT CHANGE THIS COMMENT */
             strcpy( pzOut, "='" );
@@ -246,6 +258,7 @@ cgi_run_fsm(
             /* END   == NAME_EQUAL == DO NOT CHANGE THIS COMMENT */
             break;
 
+
         case CGI_TR_SEPARATE:
             /* START == SEPARATE == DO NOT CHANGE THIS COMMENT */
             strcpy( pzOut, "';\n" );
@@ -254,6 +267,7 @@ cgi_run_fsm(
             /* END   == SEPARATE == DO NOT CHANGE THIS COMMENT */
             break;
 
+
         case CGI_TR_STASH:
             /* START == STASH == DO NOT CHANGE THIS COMMENT */
             *(pzOut++) = curCh;
@@ -261,6 +275,7 @@ cgi_run_fsm(
             /* END   == STASH == DO NOT CHANGE THIS COMMENT */
             break;
 
+
         case CGI_TR_VALUE_ESCAPE:
             /* START == VALUE_ESCAPE == DO NOT CHANGE THIS COMMENT */
             {
@@ -273,6 +288,10 @@ cgi_run_fsm(
             z[2] = NUL;
             inlen -= 2;
 
+            /*
+             *  We must backslash quote certain characters that are %-quoted
+             *  in the input string:
+             */
             switch (*(pzOut++) = (int)strtol( z, NULL, 16 )) {
             case '\'':
             case '\\':
@@ -285,12 +304,6 @@ cgi_run_fsm(
             /* END   == VALUE_ESCAPE == DO NOT CHANGE THIS COMMENT */
             break;
 
-        case CGI_TR_VALUE_SPACE:
-            /* START == VALUE_SPACE == DO NOT CHANGE THIS COMMENT */
-            *(pzOut++) = ' ';
-            outlen--;
-            /* END   == VALUE_SPACE == DO NOT CHANGE THIS COMMENT */
-            break;
 
         default:
             /* START == BROKEN MACHINE == DO NOT CHANGE THIS COMMENT */
@@ -306,11 +319,4 @@ cgi_run_fsm(
     }
     return cgi_state;
 }
-/*
- * Local Variables:
- * mode: C
- * c-file-style: "stroustrup"
- * indent-tabs-mode: nil
- * tab-width: 4
- * End:
- * end of cgi-fsm.c */
+/* end of cgi-fsm.c */
