@@ -1,12 +1,12 @@
 /*  -*- Mode: C -*-
  *
  *  expExtract.c
- *  $Id: expExtract.c,v 1.10 2003/02/15 22:58:59 bkorb Exp $
+ *  $Id: expExtract.c,v 1.15 2004/02/02 03:31:50 bkorb Exp $
  *  This module implements a file extraction function.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,11 +25,6 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-#include <string.h>
-
-#include "expr.h"
-#include "autogen.h"
-
 /*
  *  loadExtractData
  *
@@ -94,7 +89,7 @@ loadExtractData( const char* pzNewFile )
             size_t sz = fread( pzIn, 1, sbuf.st_size, fp );
             if (sz == 0) {
                 fprintf( stderr, "Error %d (%s) reading %d bytes of %s\n",
-                         errno, strerror( errno ), sbuf.st_size, pzFile );
+                         errno, strerror( errno ), (int)sbuf.st_size, pzFile );
                 AG_ABEND( "read failure" );
             }
 
@@ -252,7 +247,7 @@ extractText( const char* pzText, const char* pzStart, const char* pzEnd,
  * named ".fsm.head" and ".fsm.code".  At the end of the 'c' output
  * processing, I delete them.
 =*/
-    SCM
+SCM
 ag_scm_extract( SCM file, SCM marker, SCM caveat, SCM def )
 {
     const char* pzStart;
@@ -301,7 +296,7 @@ ag_scm_extract( SCM file, SCM marker, SCM caveat, SCM def )
  * files.  This function will search the same list for @file{file-name}, both
  * with and without the @file{.suffix}, if provided.
 =*/
-    SCM
+SCM
 ag_scm_find_file( SCM file, SCM suffix )
 {
     tSCC  zFun[] = "ag_scm_find_file";
@@ -333,7 +328,9 @@ ag_scm_find_file( SCM file, SCM suffix )
 
 /*
  * Local Variables:
- * c-file-style: "Stroustrup"
+ * mode: C
+ * c-file-style: "stroustrup"
+ * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of expExtract.c */
+ * end of agen5/expExtract.c */
