@@ -1,13 +1,13 @@
 
 /*
  *  expState.c
- *  $Id: expState.c,v 1.45 2003/12/21 04:34:52 bkorb Exp $
+ *  $Id: expState.c,v 1.48 2004/02/24 02:47:52 bkorb Exp $
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2004 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -47,7 +47,7 @@ entry_length( char* pzName )
         if (pDE == NULL)
             break;
         if (pDE->valType == VALTYP_TEXT)
-            res += strlen( pDE->pzValue );
+            res += strlen( pDE->val.pzText );
         else
             res++;
     }
@@ -115,7 +115,7 @@ find_entry_value( SCM op, SCM obj, SCM test )
             return SCM_BOOL_F; /* Cannot match string -- not a text value */
         }
 
-        field  = gh_str02scm( pE->pzValue );
+        field  = gh_str02scm( pE->val.pzText );
         result = gh_call2( op, field, test );
         if (! isIndexed)
             while (result == SCM_BOOL_F) {
@@ -124,7 +124,7 @@ find_entry_value( SCM op, SCM obj, SCM test )
                 if (pE == NULL)
                     break;
 
-                field = gh_str02scm( pE->pzValue );
+                field = gh_str02scm( pE->val.pzText );
                 result = gh_call2( op, field, test );
             }
 
@@ -147,12 +147,13 @@ find_entry_value( SCM op, SCM obj, SCM test )
      */
     pzField[-1] = '.';
     {
-        SCM field = gh_str02scm( pzField );
+        SCM field   = gh_str02scm( pzField );
         SCM result;
-        tDefStack    stack   = currDefCtx;
-        currDefCtx.pPrev     = &stack;
+        tDefCtx ctx = currDefCtx;
+
+        currDefCtx.pPrev = &ctx;
+        currDefCtx.pDefs = pE->val.pDefEntry;
 
-        currDefCtx.pDefs = (tDefEntry*)(void*)(pE->pzValue);
         result = find_entry_value( op, field, test );
 
         if (! isIndexed)
@@ -162,11 +163,11 @@ find_entry_value( SCM op, SCM obj, SCM test )
                 if (pE == NULL)
                     break;
 
-                currDefCtx.pDefs = (tDefEntry*)(void*)(pE->pzValue);
+                currDefCtx.pDefs = pE->val.pDefEntry;
                 result = find_entry_value( op, field, test );
             }
 
-        currDefCtx = stack;
+        currDefCtx = ctx;
         return result;
     }
 }
@@ -189,6 +190,38 @@ ag_scm_base_name( void )
 }
 
 
+/*=gfunc chdir
+ *
+ * what:   Change current directory
+ *
+ * exparg: dir, new directory name
+ *
+ * doc:  Sets the current directory for AutoGen.  Shell commands will run
+ *       from this directory as well.  This is a wrapper around the Guile
+ *       native function.  It returns its directory name argument and
+ *       fails the program on failure.
+=*/
+SCM
+ag_scm_chdir( SCM dir )
+{
+    tSCC zChdirDir[] = "chdir directory";
+
+    scm_chdir( dir );
+
+    /*
+     *  We're still here, so we have a valid argument.
+     */
+    if (pCurDir != NULL)
+        free( pCurDir );
+    {
+        char* pz = ag_scm2zchars( dir, zChdirDir );
+        pCurDir = malloc( SCM_LENGTH( dir ) + 1 );
+        strcpy( (char*)pCurDir, pz );
+    }
+    return dir;
+}
+
+
 /*=gfunc count
  *
  * what:   definition count
@@ -345,7 +378,7 @@ ag_scm_get( SCM agName, SCM altVal )
         return gh_str02scm( "" );
     }
 
-    return gh_str02scm( pE->pzValue );
+    return gh_str02scm( pE->val.pzText );
 }
 
 
@@ -481,11 +514,23 @@ ag_scm_suffix( void )
  *
  * what:   get the template file name
  *
+ * exparg: full_path, include full path to file, optonal
+ *
  * doc:  Returns the name of the current template file.
+ *       If @code{#t} is passed in as an argument, then the template
+ *       file is hunted for in the template search path.  Otherwise,
+ *       just the unadorned name.
 =*/
 SCM
-ag_scm_tpl_file( void )
+ag_scm_tpl_file( SCM full )
 {
+    if (gh_boolean_p( full ) && SCM_NFALSEP( full )) {
+        tSCC* sfx[] = { "tpl", NULL };
+        char z[MAXPATHLEN];
+        if (SUCCESSFUL( findFile( pzTemplFileName, z, sfx )))
+            return gh_str02scm( z );
+    }
+
     return gh_str02scm( (char*)(void*)pzTemplFileName );
 }
 
