@@ -1,6 +1,6 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
- * AutoGen Globally exported prototypes Sun Jun  1 11:40:46 PDT 2003
+ * AutoGen Globally exported prototypes Mon Feb 23 18:59:17 PST 2004
  */
 #ifndef AUTOGEN_PROTOTYPES_H
 #define AUTOGEN_PROTOTYPES_H
@@ -67,44 +67,21 @@ findEntryList( char* pzName );
 
 /* exports from defLex.c */
 
-int
+te_dp_event
 yylex( void );
 void
 yyerror( char* s );
 
 /* exports from defLoad.c */
 
-void
-readDefines( void );
-
-/* exports from defReduce.c */
-
 void
 freeEntry( tDefEntry* pDE );
 tDefEntry*
 getEntry( void );
-YYSTYPE
-addSibMacro( YYSTYPE def, YYSTYPE  list );
-YYSTYPE
-makeMacro(
-    YYSTYPE    place,
-    YYSTYPE    val,
-    teValType  type );
-YYSTYPE
-makeMacroList(
-    YYSTYPE    place,
-    YYSTYPE    list,
-    teValType  type );
-YYSTYPE
-startList( YYSTYPE entry );
-YYSTYPE
-appendList( YYSTYPE entry, YYSTYPE list );
-YYSTYPE
-findPlace( YYSTYPE name, YYSTYPE index );
-YYSTYPE
-makeEmptyDefs( void );
-YYSTYPE
-identify( YYSTYPE template );
+tDefEntry*
+findPlace( char* name, tCC* pzIndex );
+void
+readDefines( void );
 
 /* exports from expGuile.c */
 
