@@ -1,6 +1,6 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
- * Getdefs Globally exported prototypes Sun Jun  1 11:40:46 PDT 2003
+ * Getdefs Globally exported prototypes Mon Feb 23 18:59:18 PST 2004
  */
 #ifndef GETDEFS_PROTOTYPES_H
 #define GETDEFS_PROTOTYPES_H
@@ -12,9 +12,6 @@ emitDefinition( char* pzDef, char* pzOut );
 
 /* exports from gdinit.c */
 
-extern void
-fixupSubblockString( char* pz );
-
 extern void
 processEmbeddedOptions( char* pzText );
 
@@ -24,6 +21,6 @@ validateOptions( void );
 /* exports from getdefs.c */
 
 extern char*
-loadFile( char* pzFname );
+loadFile( tCC* pzFname );
 
 #endif /* GETDEFS_PROTOTYPES_H */
