@@ -2,12 +2,12 @@
 ##  -*- Mode: shell-script -*-
 ## mklibsrc.sh --   make the libopts tear-off library source tarball
 ##
-## Time-stamp:      "2002-09-21 15:22:33 bkorb"
+## Time-stamp:      "2004-02-16 11:36:11 bkorb"
 ## Maintainer:      Bruce Korb <bkorb@gnu.org>
 ## Created:         Aug 20, 2002
 ##              by: bkorb
 ## ---------------------------------------------------------------------
-## $Id: mklibsrc.sh,v 1.14 2002/09/21 22:24:35 bkorb Exp $
+## $Id: mklibsrc.sh,v 1.21 2004/02/16 22:12:51 bkorb Exp $
 ## ---------------------------------------------------------------------
 ## Code:
 
@@ -16,6 +16,9 @@ set -e -x
 top_builddir=`cd $top_builddir ; pwd`
 top_srcdir=`cd $top_srcdir ; pwd`
 
+[ -x ${top_builddir}/agen5/autogen ] || exit 0
+[ -x ${top_builddir}/columns/columns ] || exit 0
+
 tag=libopts-${AO_CURRENT}.${AO_REVISION}.${AO_AGE}
 
 cd ${top_builddir}/pkg
@@ -107,14 +110,14 @@ cat >> libopts.m4 <<-	EOMacro
 	  then
 	    LIBOPTS_LDADD="\${lo_cv_test_autoopts}"
 	    LIBOPTS_CFLAGS="\`\${aoconfig} --cflags\`"
-	    build_libopts_dir=''
+	    NEED_LIBOPTS_DIR=''
 	  else
 	    LIBOPTS_LDADD='\$(top_builddir)/libopts/libopts.la'
 	    LIBOPTS_CFLAGS='-I\$(top_srcdir)/libopts'
 	    INVOKE_LIBOPTS_MACROS
-	    build_libopts_dir=true
+	    NEED_LIBOPTS_DIR=true
 	  fi
-	  AM_CONDITIONAL([NEED_LIBOPTS], [test -n "\${build_libopts_dir}"])
+	  AM_CONDITIONAL([NEED_LIBOPTS], [test -n "\${NEED_LIBOPTS_DIR}"])
 	  AC_SUBST(LIBOPTS_LDADD)
 	  AC_SUBST(LIBOPTS_CFLAGS)
 	  AC_CONFIG_FILES([libopts/Makefile])
@@ -123,34 +126,45 @@ cat >> libopts.m4 <<-	EOMacro
 
 [ -f Makefile.am ] && rm -f Makefile.am
 
-cat > MakeDefs.inc <<-	EOMakeDefs
-	## LIBOPTS Makefile Fragment
-	if NEED_LIBOPTS
-	  LIBOPTS_DIR  = libopts
-	else
-	  LIBOPTS_DIR  =
-	endif
-	LIBOPTS_LDADD  = @LIBOPTS_LDADD@
-	LIBOPTS_CFLAGS = @LIBOPTS_CFLAGS@
-	EOMakeDefs
-
 sed s,'\${tag}',"${tag}",g ${top_srcdir}/pkg/libopts/README > README
 cp ${top_srcdir}/pkg/libopts/COPYING* .
 
 exec 3> Makefile.am
 cat >&3 <<-	EOMakefile
 	## LIBOPTS Makefile
-	EXTRA_DIST            = `echo COPYING*` MakeDefs.inc compat
+	EXTRA_DIST            = `echo COPYING*` compat
 	MAINTAINERCLEANFILES  = Makefile.in
 	lib_LTLIBRARIES       = libopts.la
 	libopts_la_SOURCES    = \\
 	EOMakefile
 
+cols="${top_builddir}/columns/columns -I4 --spread=1"
+
 ls -1 *.[ch] | \
-  ${top_builddir}/columns/columns -I4 --spread=1 --line-sep='  \' >&3
+   ${cols} --line-sep="  \\" >&3
 
 exec 3>&-
 
+cat > MakeDefs.inc <<- EODefs
+	if NEED_LIBOPTS
+	LIBOPTS_DIR = libopts
+	else
+	LIBOPTS_DIR =
+	endif
+	EODefs
+
+if gzip --version > /dev/null 2>&1
+then
+  gz=gzip
+  sfx=tar.gz
+else
+  gz=compress
+  sfx=tar.Z
+fi
+
 cd ..
-tar cvf - ${tag} | gzip --best > ${top_builddir}/autoopts/${tag}.tar.gz
+echo ! cd `pwd`
+echo ! tar cvf ${tag}.${sfx} ${tag}
+tar cvf - ${tag} | $gz --best > ${top_builddir}/autoopts/${tag}.${sfx}
 rm -rf ${tag}
+## end of mklibsrc.sh
